@@ -1,4 +1,22 @@
+"""
+Module defining class (`DataArray`) used to represent Numpy arrays in XML
+model.
+"""
 import functools
+import numpy as np
+
+DTYPE_TO_VTK = {
+    np.dtype(np.float32): 'Float32',
+    np.dtype(np.float64): 'Float64',
+    np.dtype(np.int8): 'Int8',
+    np.dtype(np.int16): 'Int16',
+    np.dtype(np.int32): 'Int32',
+    np.dtype(np.int64): 'Int64',
+    np.dtype(np.uint8): 'UInt8',
+    np.dtype(np.uint16): 'UInt16',
+    np.dtype(np.uint32): 'UInt32',
+    np.dtype(np.uint64): 'UInt64',
+}
 
 
 class DataArray:
@@ -19,7 +37,8 @@ class DataArray:
         spatial_axes = list(spatial_axes)
 
         if data.ndim < len(spatial_axes):
-            raise Exception('Dimensions of data smaller than space dimensions')
+            raise ValueError(
+                'Dimensions of data smaller than space dimensions')
 
         for ax in spatial_axes:
             axes.remove(ax)
@@ -29,19 +48,34 @@ class DataArray:
 
         if components_order == 'C':
             axes.reverse()
+        elif components_order == 'F':
+            pass
         else:
-            raise Exception('Unrecognized components order')
+            raise ValueError('Unrecognized components order')
 
         axes += spatial_axes
 
         # Hopefully this is a view
         self.flat_data = self.data.transpose(*axes).reshape(-1, order='F')
 
+        try:
+            data_type = DTYPE_TO_VTK[self.flat_data.dtype]
+        except KeyError:
+            raise TypeError(
+                'Array dtype {} is not supported by VTK'.format(
+                    self.flat_data.dtype))
+
         self.attributes = {
             "Name": name,
-            "type": str(self.flat_data.dtype).capitalize(),
-            "NumberOfComponents": str(nb_components)
+            "type": data_type,
+            "NumberOfComponents": str(nb_components),
+            "NumberOfTuples": str(self.flat_data.size),
         }
 
-    def __str__(self):
+        if 'Int' in data_type:
+            self.format_str = '%d'
+        else:
+            self.format_str = '%.18e'
+
+    def __str__(self):  # pragma: no cover
         return self.attributes.__str__()
